==> combo-sdk-unity_2.12.0.zip: com.seayoo.sdk/ThinkingData/Plugins/iOS/ThinkingDataCore/Classes/ThinkingDataCore.h <==
//
//  ThinkingDataCore.h
//  ThinkingDataCore
//
//  Created by Hale on 2023/7/24.
//

#import <Foundation/Foundation.h>

// In this header, you should import all the public headers of your framework using statements like #import <ThinkingDataCore/PublicHeader.h>

#if __has_include(<ThinkingDataCore/TDCoreInfo.h>)
#import <ThinkingDataCore/TDCoreInfo.h>
#else
#import "TDCoreInfo.h"
#endif

#if __has_include(<ThinkingDataCore/TDJSONUtil.h>)
#import <ThinkingDataCore/TDJSONUtil.h>
#else
#import "TDJSONUtil.h"
#endif

#if __has_include(<ThinkingDataCore/NSData+TDGzip.h>)
#import <ThinkingDataCore/NSData+TDGzip.h>
#else
#import "NSData+TDGzip.h"
#endif

#if __has_include(<ThinkingDataCore/NSDate+TDCore.h>)
#import <ThinkingDataCore/NSDate+TDCore.h>
#else
#import "NSDate+TDCore.h"
#endif

#if __has_include(<ThinkingDataCore/TDNewSwizzle.h>)
#import <ThinkingDataCore/TDNewSwizzle.h>
#else
#import "TDNewSwizzle.h"
#endif

#if __has_include(<ThinkingDataCore/TDClassHelper.h>)
#import <ThinkingDataCore/TDClassHelper.h>
#else
#import "TDClassHelper.h"
#endif

#if __has_include(<ThinkingDataCore/TDMethodHelper.h>)
#import <ThinkingDataCore/TDMethodHelper.h>
#else
#import "TDMethodHelper.h"
#endif

#if __has_include(<ThinkingDataCore/NSObject+TDSwizzle.h>)
#import <ThinkingDataCore/NSObject+TDSwizzle.h>
#else
#import "NSObject+TDSwizzle.h"
#endif

#if __has_include(<ThinkingDataCore/TDSwizzler.h>)
#import <ThinkingDataCore/TDSwizzler.h>
#else
#import "TDSwizzler.h"
#endif

#if __has_include(<ThinkingDataCore/TDOSLog.h>)
#import <ThinkingDataCore/TDOSLog.h>
#else
#import "TDOSLog.h"
#endif

#if __has_include(<ThinkingDataCore/NSString+TDCore.h>)
#import <ThinkingDataCore/NSString+TDCore.h>
#else
#import "NSString+TDCore.h"
#endif

#if __has_include(<ThinkingDataCore/TDApp.h>)
#import <ThinkingDataCore/TDApp.h>
#else
#import "TDApp.h"
#endif

#if __has_include(<ThinkingDataCore/TDSettings.h>)
#import <ThinkingDataCore/TDSettings.h>
#else
#import "TDSettings.h"
#endif

#if __has_include(<ThinkingDataCore/TDLogChannelProtocol.h>)
#import <ThinkingDataCore/TDLogChannelProtocol.h>
#else
#import "TDLogChannelProtocol.h"
#endif

#if __has_include(<ThinkingDataCore/TDLogConstant.h>)
#import <ThinkingDataCore/TDLogConstant.h>
#else
#import "TDLogConstant.h"
#endif

#if __has_include(<ThinkingDataCore/TDNotificationManager+Core.h>)
#import <ThinkingDataCore/TDNotificationManager+Core.h>
#else
#import "TDNotificationManager+Core.h"
#endif

#if __has_include(<ThinkingDataCore/TDNotificationManager+Analytics.h>)
#import <ThinkingDataCore/TDNotificationManager+Analytics.h>
#else
#import "TDNotificationManager+Analytics.h"
#endif

#if __has_include(<ThinkingDataCore/TDNotificationManager+Networking.h>)
#import <ThinkingDataCore/TDNotificationManager+Networking.h>
#else
#import "TDNotificationManager+Networking.h"
#endif

#if __has_include(<ThinkingDataCore/TDNotificationManager+RemoteConfig.h>)
#import <ThinkingDataCore/TDNotificationManager+RemoteConfig.h>
#else
#import "TDNotificationManager+RemoteConfig.h"
#endif

#if __has_include(<ThinkingDataCore/TDCoreDatabase.h>)
#import <ThinkingDataCore/TDCoreDatabase.h>
#else
#import "TDCoreDatabase.h"
#endif

#if __has_include(<ThinkingDataCore/TDCalibratedTime.h>)
#import <ThinkingDataCore/TDCalibratedTime.h>
#else
#import "TDCalibratedTime.h"
#endif

#if __has_include(<ThinkingDataCore/TDCoreDeviceInfo.h>)
#import <ThinkingDataCore/TDCoreDeviceInfo.h>
#else
#import "TDCoreDeviceInfo.h"
#endif

#if __has_include(<ThinkingDataCore/NSObject+TDCore.h>)
#import <ThinkingDataCore/NSObject+TDCore.h>
#else
#import "NSObject+TDCore.h"
#endif

#if __has_include(<ThinkingDataCore/NSURL+TDCore.h>)
#import <ThinkingDataCore/NSURL+TDCore.h>
#else
#import "NSURL+TDCore.h"
#endif

#if __has_include(<ThinkingDataCore/NSNumber+TDCore.h>)
#import <ThinkingDataCore/NSNumber+TDCore.h>
#else
#import "NSNumber+TDCore.h"
#endif

#if __has_include(<ThinkingDataCore/TDMediator+RemoteConfig.h>)
#import <ThinkingDataCore/TDMediator+RemoteConfig.h>
#else
#import "TDMediator+RemoteConfig.h"
#endif

#if __has_include(<ThinkingDataCore/TDMediator+Analytics.h>)
#import <ThinkingDataCore/TDMediator+Analytics.h>
#else
#import "TDMediator+Analytics.h"
#endif

#if __has_include(<ThinkingDataCore/TDMediator+Strategy.h>)
#import <ThinkingDataCore/TDMediator+Strategy.h>
#else
#import "TDMediator+Strategy.h"
#endif

#if __has_include(<ThinkingDataCore/TDCorePresetProperty.h>)
#import <ThinkingDataCore/TDCorePresetProperty.h>
#else
#import "TDCorePresetProperty.h"
#endif

#if __has_include(<ThinkingDataCore/TDCorePresetDisableConfig.h>)
#import <ThinkingDataCore/TDCorePresetDisableConfig.h>
#else
#import "TDCorePresetDisableConfig.h"
#endif

==> combo-sdk-unity_2.17.0.zip: com.seayoo.sdk/ThinkingData/Plugins/iOS/ThinkingDataCore/Classes/ThinkingDataCore.h <==
//
//  ThinkingDataCore.h
//  ThinkingDataCore
//
//  Created by Hale on 2023/7/24.
//

#import <Foundation/Foundation.h>

// In this header, you should import all the public headers of your framework using statements like #import <ThinkingDataCore/PublicHeader.h>

#if __has_include(<ThinkingDataCore/TDCoreInfo.h>)
#import <ThinkingDataCore/TDCoreInfo.h>
#import <ThinkingDataCore/TDJSONUtil.h>
#import <ThinkingDataCore/NSData+TDGzip.h>
#import <ThinkingDataCore/NSDate+TDCore.h>
#import <ThinkingDataCore/TDNewSwizzle.h>
#import <ThinkingDataCore/TDClassHelper.h>
#import <ThinkingDataCore/TDMethodHelper.h>
#import <ThinkingDataCore/NSObject+TDSwizzle.h>
#import <ThinkingDataCore/TDSwizzler.h>
#import <ThinkingDataCore/TDOSLog.h>
#import <ThinkingDataCore/NSString+TDCore.h>
#import <ThinkingDataCore/TDApp.h>
#import <ThinkingDataCore/TDSettings.h>
#import <ThinkingDataCore/TDLogChannelProtocol.h>
#import <ThinkingDataCore/TDLogConstant.h>
#import <ThinkingDataCore/TDNotificationManager+Core.h>
#import <ThinkingDataCore/TDNotificationManager+Analytics.h>
#import <ThinkingDataCore/TDNotificationManager+Networking.h>
#import <ThinkingDataCore/TDNotificationManager+RemoteConfig.h>
#import <ThinkingDataCore/TDCoreDatabase.h>
#import <ThinkingDataCore/TDCalibratedTime.h>
#import <ThinkingDataCore/TDCoreDeviceInfo.h>
#import <ThinkingDataCore/NSObject+TDCore.h>
#import <ThinkingDataCore/NSURL+TDCore.h>
#import <ThinkingDataCore/NSNumber+TDCore.h>
#import <ThinkingDataCore/TDMediator+RemoteConfig.h>
#import <ThinkingDataCore/TDMediator+Analytics.h>
#import <ThinkingDataCore/TDMediator+Sensitive.h>
#import <ThinkingDataCore/TDCorePresetProperty.h>
#import <ThinkingDataCore/TDCorePresetDisableConfig.h>
#import <ThinkingDataCore/NSDictionary+TDCore.h>
#import <ThinkingDataCore/TDCoreKeychainHelper.h>
#import <ThinkingDataCore/TDCoreLog.h>
#import <ThinkingDataCore/TDCoreWeakProxy.h>
#import <ThinkingDataCore/TDKeychainManager.h>
#import <ThinkingDataCore/TDLogChannelConsole.h>
#import <ThinkingDataCore/TDLogMessage.h>
#import <ThinkingDataCore/TDMediator.h>
#import <ThinkingDataCore/TDMediator+Strategy.h>
#import <ThinkingDataCore/TDNTPServer.h>
#import <ThinkingDataCore/TDNTPTypes.h>
#import <ThinkingDataCore/TDSettingsPrivate.h>
#else
#import "TDCoreInfo.h"
#import "TDJSONUtil.h"
#import "NSData+TDGzip.h"
#import "NSDate+TDCore.h"
#import "TDNewSwizzle.h"
#import "TDClassHelper.h"
#import "TDMethodHelper.h"
#import "NSObject+TDSwizzle.h"
#import "TDSwizzler.h"
#import "TDOSLog.h"
#import "NSString+TDCore.h"
#import "TDApp.h"
#import "TDLogConstant.h"
#import "TDSettings.h"
#import "TDLogChannelProtocol.h"
#import "TDNotificationManager+Core.h"
#import "TDNotificationManager+Analytics.h"
#import "TDNotificationManager+Networking.h"
#import "TDNotificationManager+RemoteConfig.h"
#import "TDCoreDatabase.h"
#import "TDCalibratedTime.h"
#import "TDCoreDeviceInfo.h"
#import "NSObject+TDCore.h"
#import "NSURL+TDCore.h"
#import "NSNumber+TDCore.h"
#import "TDMediator+RemoteConfig.h"
#import "TDMediator+Analytics.h"
#import "TDMediator+Sensitive.h"
#import "TDCorePresetProperty.h"
#import "TDCorePresetDisableConfig.h"
#import "NSDictionary+TDCore.h"
#import "TDCoreKeychainHelper.h"
#import "TDCoreLog.h"
#import "TDCoreWeakProxy.h"
#import "TDKeychainManager.h"
#import "TDLogChannelConsole.h"
#import "TDLogMessage.h"
#import "TDMediator.h"
#import "TDMediator+Strategy.h"
#import "TDNTPServer.h"
#import "TDNTPTypes.h"
#import "TDSettingsPrivate.h"
#endif
